@@ -24,6 +24,11 @@
 #include <QObject>
 #include <QVariant>
 
+#define KWIN_VERSION_CHECK(major, minor, patch, build) ((major<<24)|(minor<<16)|(patch<<8)|build)
+#ifdef KWIN_VERSION_STR
+#define KWIN_VERSION KWIN_VERSION_CHECK(KWIN_VERSION_MAJ, KWIN_VERSION_MIN, KWIN_VERSION_PAT, KWIN_VERSION_BUI)
+#endif
+
 class KWinUtils : public QObject
 {
     Q_OBJECT
@@ -41,10 +46,14 @@ public:
 
     static QObject *findObjectByClassName(const QByteArray &name, const QObjectList &list);
 
+    static int kwinBuildVersion();
+    static int kwinRuntimeVersion();
+
     static QObject *workspace();
     static QObject *scripting();
     static QObject *tabBox();
     static QObject *cursor();
+    static QObject *virtualDesktop();
 
     static QObjectList clientList();
     static void clientUpdateCursor(QObject *client);
@@ -52,6 +61,34 @@ public:
 
     static QFunctionPointer resolve(const char *symbol);
 
+    static qulonglong getWindowId(const QObject *client, bool *ok = nullptr);
+
+    static uint virtualDesktopCount();
+    static uint currentVirtualDesktop();
+
+    struct Window {
+        static bool isFullMaximized(const QObject *window);
+        static bool fullmaximizeWindow(QObject *window);
+        static bool unmaximizeWindow(QObject *window);
+        static void setWindowMinimize(QObject *window, bool on);
+        static void closeWindow(QObject *window);
+
+        static bool canMaximize(const QObject *window);
+        static bool canMinimize(const QObject *window);
+        static bool canMove(const QObject *window);
+        static bool canResize(const QObject *window);
+        static bool canClose(const QObject *window);
+
+        static bool isKeepAbove(const QObject *window);
+        static void setKeepAbove(QObject *window, bool on);
+        static bool isOnAllDesktops(const QObject *window);
+        static void setOnAllDesktops(QObject *window, bool on);
+        static int windowDesktop(const QObject *window);
+        static void setWindowDesktop(QObject *window, int desktop);
+
+        static void performWindowOperation(QObject* window, const QString &opName, bool restricted = false);
+    };
+
     Q_INVOKABLE quint32 getXcbAtom(const QString &name, bool only_if_exists) const;
     Q_INVOKABLE bool isSupportedAtom(quint32 atom) const;
     Q_INVOKABLE QVariant getGtkFrame(const QObject *window) const;
